#!/usr/bin/env python

import re
import os
import calendar

from pathlib import Path, PurePath

class Archives():
    
    def __init__(self):
        
        #On définit le format de fichier .zip attendu
        self.archiveRegex = re.compile(r'[0-9]{13}[A-Z]{1}([0-9][0-9])?_(DT|DICT|DDC|ATU).zip')
        self.archivesList = list()
        
    def search(self, searchDir):
        """
        Recherche, dans le répertoire indiqué en premier paramètre,
        les fichiers .zip dont les noms correspondent à l'expression régulière donnée en second paramètre.
        """
        if Path(searchDir).exists():
            # On liste les fichiers contenus dans le dossier de recherche
            filesList = Path(searchDir).iterdir()
            # On filtre la liste pour n'obtenir que les fichiers correspondant à l'expression régulière
            self.archivesList = [Declaration(f) for f in filesList if re.match(self.archiveRegex, f.name)]
        
            self.archivesList.sort(key=lambda declaration: declaration.fileName)

        return self.archivesList

class Declaration():
    
    def __init__(self, path):
        
        path = Path(path)
        
        self.fileName = path.name
        self.filePath = path.resolve()
        self.dType = self.getType(path) 
        self.numero = self.getNumero(path)
        self.date = self.getDate(path)
        self.name = self.getName(path)

    def getName(self, path):
        """
        Retourne l'intitulé complet de la déclaration dans un format lisible
        """
        return f'{self.getType(path)} n° {self.getNumero(path)} du {self.getDate(path)}'
    
    def getType(self, path):
        """
        Retourne le type de déclaration
        """
    
        declarationCodes = {'DT': 'DT', 'DICT': 'DICT',
                            'DDC': 'DT-DICT conjointe', 'ATU': 'ATU'}
        
        fileName = path.stem
        return declarationCodes[fileName.split('_')[1]]
    
    def getNumero(self, path):
        """
        Retourne le numéro de la déclaration
        """
        fileName = path.stem
        return fileName.split('_')[0][8:].lstrip('0')
    
    def getDate(self, path):
        """
        Retourne la date de la déclaration
        """
        fileName = path.stem
        dayOfMonth = fileName[6:8].lstrip('0')
        month = calendar.month_name[int(fileName[4:6])]
        year = fileName[0:4]
        day = calendar.day_name[calendar.weekday(int(year), int(fileName[4:6]), int(dayOfMonth))]
        
        return f'{day} {dayOfMonth} {month} {year}'


#!/usr/bin/env python

import time
from pathlib import Path, PurePath

from PyQt5 import QtCore, QtGui
from PyQt5.QtWidgets import QApplication, QMainWindow, QFileDialog
from DeclaTravaux.ui_main_window import Ui_Main_Window
from DeclaTravaux import images_rc

from DeclaTravaux.configuration import Configuration
from DeclaTravaux.archives import Archives, Declaration
from DeclaTravaux.transmission_process import TransmissionProcess

class MainWindow(QMainWindow, Ui_Main_Window):

    def __init__(self, parent=None):
        super().__init__(parent)
        self.setupUi(self)

        # Chargement du fichier de configuration
        self.cfg = Configuration()
        
        # Masquage de la fenêtre « À Propos »
        fixAbout = self.textBrowserAbout.sizePolicy()
        fixAbout.setRetainSizeWhenHidden(True)
        self.textBrowserAbout.setSizePolicy(fixAbout)
        self.textBrowserAbout.setProperty('visible', False)

        # Masquage du bouton « Précédent » au démarrage
        self.pushButtonPrevious.setProperty('visible', False)

        # Remplissage du formulaire « Paramètres »
        self.fillParameters()
        
        # Ajout d'un validator sur lineEditFileSelection
        validator = QtGui.QRegExpValidator(QtCore.QRegExp('(.:)?.*/[0-9]{13}[A-Z]{1}([0-9][0-9])?_(DT|DICT|DDC|ATU).zip'), self.lineEditFile)
        self.lineEditFile.setValidator(validator)
        
        # Masquage de la ligne d'erreur
        fixFileError = self.labelFileError.sizePolicy()
        fixFileError.setRetainSizeWhenHidden(True)
        self.labelFileError.setSizePolicy(fixFileError)
        self.labelFileError.setProperty('visible', False)
        
        # S'il s'agit du premier lancement du logiciel,
        # le bouton « Démarrer » est désactivé
        if int(self.cfg['PremierLancement']):
            self.pushButtonNext.setEnabled(False)

        # Connexion des signaux vers les slots
        self.pushButtonAbout.toggled.connect(self.toggleAbout)

        self.pushButtonQuit.clicked.connect(self.close)
        self.pushButtonParameters.clicked.connect(self.showParameters)
        self.pushButtonPrevious.clicked.connect(self.goPrevious)
        self.pushButtonNext.clicked.connect(self.goNext)

        self.pushButtonSearchDir.clicked.connect(self.browseParameters)
        self.pushButtonWorkDir.clicked.connect(self.browseParameters)
        self.pushButtonParamCancel.clicked.connect(self.quitParameters)
        self.pushButtonParamValidate.clicked.connect(self.quitParameters)

        self.pushButtonBrowse.clicked.connect(self.browse)
        self.lineEditFile.textEdited.connect(self.checkFileFormat)
        self.listWidget.itemSelectionChanged.connect(lambda: self.activateButtonNext(True))


    # Méthode affichant la page suivante
    def goNext(self):

        currentPage = self.stackedWidget.currentWidget()


        # Si la page actuelle est la page d'accueil
        # On lance la recherche d'archives
        # La page suivante dépend du résultat de la recherche
        if currentPage is self.pageStart:

            archives = Archives()
            self.archivesList = archives.search(self.cfg['RepertoireRecherche'])

            # S'il n'y a aucune archive trouvée,
            # la page suivante est pageFileSelection
            if len(self.archivesList) == 0:
                self.pushButtonNext.setEnabled(False)
                self.stackedWidget.setCurrentWidget(self.pageFileSelection)

            # Si une seule archive est trouvée,
            # la page suivante est pageConfirmation
            elif len(self.archivesList) == 1:
                self.declaration = self.archivesList[0]
                self.setLabelConfirmation(self.declaration.dType, self.declaration.numero, self.declaration.date)
                self.stackedWidget.setCurrentWidget(self.pageConfirmation)

            # Si plusieurs archives sont trouvées,
            # le widget Liste est rempli
            # la page suivante est pageArchiveChoose
            else:
                
                # La liste est remplie selon les archives trouvées
                self.listWidget.clear()
                
                for declaration in self.archivesList:
                    self.listWidget.addItem(declaration.name)

                self.pushButtonNext.setEnabled(False)
                self.stackedWidget.setCurrentWidget(self.pageArchiveChoose)

            # Dans tous les cas, on masque le bouton « Paramètres »,
            # on affiche le bouton « Précédent »
            # et le bouton « Démarrer » est modifié en « Suivant »
            self.pushButtonParameters.setProperty('visible', False)
            self.pushButtonPrevious.setProperty('visible', True)
            self.pushButtonNext.setText('Suivant')

        
        elif currentPage in (self.pageFileSelection, self.pageArchiveChoose):
                        
            # Si la page actuelle est pageFileSelection,
            # la page suivante est pageConfirmation
            if currentPage is self.pageFileSelection:
                if self.lineEditFile.hasAcceptableInput():
                    self.declaration = Declaration(self.lineEditFile.text())
                    self.stackedWidget.setCurrentWidget(self.pageConfirmation)
                else:
                    return 0
            
            # Si la page actuelle est pageArchiveChoose
            # la page suivante est pageConfirmation
            elif currentPage is self.pageArchiveChoose:
                self.declaration = self.archivesList[self.listWidget.currentRow()]
                self.stackedWidget.setCurrentWidget(self.pageConfirmation)
            
            self.setLabelConfirmation(self.declaration.dType, self.declaration.numero, self.declaration.date)
            
        # Si la page actuelle est pageConfirmation,
        # la page suivante est pageProgress
        elif currentPage is self.pageConfirmation:
            self.stackedWidget.setCurrentWidget(self.pageProgress)

            # Les différents boutons sont masqués
            self.pushButtonQuit.setProperty('visible', False)
            self.pushButtonPrevious.setProperty('visible', False)
            self.pushButtonNext.setProperty('visible', False)

            # Boucle sur la barre de progression
            i = 0
            self.progressBar.setMinimum(0)
            self.progressBar.setMaximum(5)
            
            errorType, errorText = False, False
            
            for step in TransmissionProcess(self.declaration):
                
                if type(step) is tuple:
                    errorType, errorText = step
                    break
                
                self.labelStep.setText(step + '...')
                self.progressBar.setValue(i)
                i += 1

            # Une fois le traitement terminé,
            # la dernière page est affichée
            
            if errorType:
                self.labelEndIcon.setPixmap(QtGui.QPixmap(":/images/cancel.svg"))
                self.labelEnd1.setText('La déclaration n’a pas été télétransmise.')
                self.labelEnd1.setStyleSheet('color: rgb(226,87,76);')
                self.labelEnd2.setText(errorText)
                self.labelEnd2.setStyleSheet('color: rgb(226,87,76);')
                self.pushButtonNext.setText('Réessayer')
                icon = QtGui.QIcon.fromTheme('edit-redo')
                
            else:
                self.labelEndIcon.setPixmap(QtGui.QPixmap(":/images/checked.svg"))
                self.labelEnd1.setText('La déclaration a été télétransmise.')
                self.labelEnd1.setStyleSheet('color: rgb(61, 179, 158);')
                self.labelEnd2.setText(f'Un courriel récapitulatif a été envoyé à {self.cfg["AdresseElectronique"]}.')
                self.labelEnd2.setStyleSheet('color: rgb(61, 179, 158);')
                self.pushButtonNext.setText('Nouvelle déclaration')
                icon = QtGui.QIcon.fromTheme('document-new')
            
            self.stackedWidget.setCurrentWidget(self.pageEnd)
            self.pushButtonQuit.setProperty('visible', True)
            self.pushButtonNext.setIcon(icon)
            self.pushButtonNext.setProperty('visible', True)

        # Si la page actuelle est pageEnd,
        # la page d'accueil est affichée
        elif currentPage is self.pageEnd:
            self.stackedWidget.setCurrentWidget(self.pageStart)
            self.pushButtonNext.setText('Démarrer')
            icon = QtGui.QIcon.fromTheme('go-next')
            self.pushButtonNext.setIcon(icon)
            self.pushButtonParameters.setProperty('visible', True)

        else:
            self.stackedWidget.setCurrentIndex((self.stackedWidget.currentIndex()+1) % self.stackedWidget.count())

    #  Méthode affichant la page précédente
    def goPrevious(self):

        currentPage = self.stackedWidget.currentWidget()

        # Si la page actuelle est pageSelection ou pageArchiveChoose,
        # la page précédente est pageStart
        if currentPage in (self.pageFileSelection, self.pageArchiveChoose):
            
            self.stackedWidget.setCurrentWidget(self.pageStart)
            self.pushButtonNext.setEnabled(True)
            self.lineEditFile.setText('')
            self.listWidget.clear()

            # Masquage bouton Précédent / Affichage bouton Paramètres
            # Bouton Suivant renommé en Démarrer
            self.pushButtonPrevious.setProperty('visible', False)
            self.pushButtonParameters.setProperty('visible', True)
            self.pushButtonNext.setText('Démarrer')

        # Si la page actuelle est pageConfirmation,
        # la page précédente dépend du nombre d'archives qui avaient été trouvées
        elif currentPage is self.pageConfirmation:
            pages = {0: self.pageFileSelection, 1: self.pageStart, 2: self.pageArchiveChoose}
            self.stackedWidget.setCurrentWidget(pages.get(len(self.archivesList), self.pageArchiveChoose))
            
            if len(self.archivesList) == 1:
                self.pushButtonPrevious.setProperty('visible', False)
                self.pushButtonParameters.setProperty('visible', True)
            
        else:
            self.stackedWidget.setCurrentIndex((self.stackedWidget.currentIndex()-1) % self.stackedWidget.count())

    # Affichage des paramètres
    def showParameters(self):
        self.stackedWidget.setCurrentWidget(self.pageParameters)
        self.stackedWidgetButtons.setCurrentWidget(self.stackedWidgetButtonsParameters)

    # Validation ou annulation des paramètres
    def quitParameters(self):

        # Si le bouton Valider est appelé,
        # on enregistre les paramètres
        if self.sender().objectName() == 'pushButtonParamValidate':

            self.cfg.parameters = {'RepertoireRecherche': self.lineEditSearchDir.text(),
                                    'RepertoireDeclarations': self.lineEditWorkDir.text(),
                                    'AdresseElectronique': self.lineEditMail.text(),
                                    'ServeurSMTP': self.lineEditSmtpServer.text(),
                                    'PortServeurSMTP': self.lineEditSmtpPort.text(),
                                    'NomExpediteur': self.lineEditExpeditorName.text(),
                                    }
            self.cfg.password = self.lineEditPassword.text()

            self.pushButtonNext.setEnabled(True)

        # Si le bouton Annuler est appelé,
        # les anciens paramètres sont restaurés dans le formulaire
        else:
            self.fillParameters()

        self.stackedWidget.setCurrentWidget(self.pageStart)
        self.stackedWidgetButtons.setCurrentWidget(self.stackedWidgetButtonsDefault)

    def toggleAbout(self):
        state = self.textBrowserAbout.property('visible')
        self.textBrowserAbout.setProperty('visible', not state)

    def browse(self):
        (fileUrl, f) = QFileDialog.getOpenFileName(self, 'Choisir une archive', '~/', 'Archives (*.zip);;Tous les fichiers (*)')
        if fileUrl:
            self.lineEditFile.setText(fileUrl)
            self.checkFileFormat()

    def browseParameters(self):
        directoryUrl = QFileDialog.getExistingDirectory(self, 'Choisir un répertoire', str(Path().home()), QFileDialog.ShowDirsOnly)
        if directoryUrl:
            if self.sender().objectName() == 'pushButtonSearchDir':
                self.lineEditSearchDir.setText(directoryUrl)
            else:
                self.lineEditWorkDir.setText(directoryUrl)
    
    def activateButtonNext(self, boolean):
        self.pushButtonNext.setEnabled(boolean)

    def checkFileFormat(self):
        if not self.lineEditFile.hasAcceptableInput() or not Path(self.lineEditFile.text()).exists():
            self.lineEditFile.setStyleSheet('color: rgb(226,87,76);')
            self.labelFileError.setProperty('visible', True)
            self.activateButtonNext(False)
            
            if not self.lineEditFile.hasAcceptableInput():
                self.labelFileError.setText('Le format de l’archive sélectionnée est incorrect.')
            else:
                self.labelFileError.setText('Le fichier indiqué n’existe pas.')
            
        else:
            self.lineEditFile.setStyleSheet('')
            self.labelFileError.setProperty('visible', False)
            self.activateButtonNext(True)

    def fillParameters(self):
        self.lineEditSearchDir.setText(self.cfg['RepertoireRecherche'])
        self.lineEditWorkDir.setText(self.cfg['RepertoireDeclarations'])
        self.lineEditMail.setText(self.cfg['AdresseElectronique'])
        self.lineEditPassword.setText(self.cfg.password)
        self.lineEditSmtpServer.setText(self.cfg['ServeurSMTP'])
        self.lineEditSmtpPort.setText(self.cfg['PortServeurSMTP'])
        self.lineEditExpeditorName.setText(self.cfg['NomExpediteur'])
    
    def setLabelConfirmation(self, dType, numero, date):
        
        det = 'L’' if dType == 'ATU' else 'La '
        
        self.labelConfirmation.setText(f"""
                    <style>
                    p {{margin: 15px; line-height: 125%; font-size: 14pt; text-align: center}};
                    b {{white-space: nowrap;}}
                    </style>                    
                    <p>
                        {det}<b>{dType}</b> n<span style="vertical-align: super;">o</span> 
                        <b>{numero}</b> du <b>{date.replace(' ', '&nbsp;')}</b> a été sélectionnée.
                    </p>
                    <p>
                        Souhaitez-vous procéder à sa télétransmission ?
                    </p>""")


#!/usr/bin/env python

import configparser
import platform
import os
import keyring

from pathlib import Path, PurePath

class Configuration():

    def __init__(self):

        config = configparser.ConfigParser()
        config.optionxform = str

        # Le chemin du fichier de configuration dépend du système d'exploitation
        self.configFilePath = self.getConfigFilePath()

        # Si le fichier de configuration n'existe pas, on le crée
        
        if not Path(self.configFilePath).exists():
            self.createConfigFile(self.configFilePath)

        # On charge les informations
        config.read(self.configFilePath)

        self._parameters = config
        self._password = keyring.get_password('DeclaTravaux', os.getlogin())

    def __getitem__(self, key):
        
        if key in ('PremierLancement', 'RepertoireDeclarations', 'RepertoireRecherche'):
            return self._parameters['Configuration'][key]
        
        elif key in ('AdresseElectronique', 'ServeurSMTP', 'PortServeurSMTP', 'NomExpediteur'):
            return self._parameters['Courriels'][key]
    
    def __setitem__(self, key, value):
        self.parameters = {key: value}

    def getConfigFilePath(self):
        """
        Retourne le chemin du fichier de configuration de l'application
        """
        cheminFichier = ''

        # Le chemin du fichier de configuration dépend du système d'exploitation
        if platform.system() == 'Linux':

            try:
                configDir = os.environ['XDG_CONFIG_HOME']
            except KeyError:
                configDir = PurePath(Path.home(), '.config/')
                #os.path.join(os.path.expanduser('~'), '.config')
            finally:
                configFilePath = PurePath(configDir, 'declaTravaux', 'declaTravaux.conf')
                #os.path.join(configDir, 'declaTravaux', 'declaTravaux.conf')

        elif platform.system() == 'Windows':
            configFilePath = PurePath(os.environ['AppData'], 'DeclaTravaux', 'DeclaTravaux.conf')
            #os.path.join(os.environ['AppData'], 'DeclaTravaux', 'DeclaTravaux.conf')

        return configFilePath

    def createConfigFile(self, filePath):
        """
        Fonction créant le fichier de configuration par défaut
        """

        config = configparser.ConfigParser()
        config.optionxform = str
        
        workDir = Path(Path.home(), 'Documents', 'DéclaTravaux')
        #workDir = os.path.join(os.path.expanduser('~'), 'Documents', 'DéclaTravaux')

        # Par défaut, les archives sont recherchées dans le répertoire « Téléchargements »
        # Si ce dernier n'est pas trouvé, elles sont recherchées dans le dossier de l'utilisateur
        if platform.system() == 'Linux':

            try:
                searchDir = Path(os.environ['XDG_DOWNLOAD_DIR'])

            except KeyError:
                searchDir = Path(Path.home(), 'Téléchargements')
                #os.path.join(os.path.expanduser('~'), 'Téléchargements')

                if not searchDir.exists():
                #if not os.path.isdir(searchDir):
                    searchDir = Path.home()
                    #os.path.expanduser('~')

        elif platform.system() == 'Windows':
            searchDir = Path(Path.home(), 'Downloads')
            #os.path.join(os.path.expanduser('~'), 'Downloads')


        config['Configuration'] = {'PremierLancement': '1',
                                    'RepertoireDeclarations': str(workDir),
                                    'RepertoireRecherche': str(searchDir)}

        config['Courriels'] = { 'AdresseElectronique': '',
                                'ServeurSMTP': '',
                                'PortServeurSMTP': '',
                                'NomExpediteur': ''}


        #os.makedirs(os.path.dirname(filePath), exist_ok=True)
        Path(filePath.parent).mkdir(exist_ok=True)
        
        with open(filePath, 'w') as configFile:
            config.write(configFile)

    @property
    def parameters(self):
        return self._parameters

    @parameters.setter
    def parameters(self, paramDict):

        config = self._parameters

        # Le paramètre PremierLancement est automatiquement affecté de la valeur 0
        config['Configuration']['PremierLancement'] = '0'

        # On boucle les paramètres donnés en arguments
        # S'ils correspondent aux paramètres attendus, on modifie les paramètres
        for parameter, value in paramDict.items():

            if parameter in ('RepertoireDeclarations', 'RepertoireRecherche'):

                config['Configuration'][parameter] = value

            elif parameter in ( 'AdresseElectronique',
                                'ServeurSMTP', 'PortServeurSMTP', 'NomExpediteur'):

                config['Courriels'][parameter] = value

        # Le fichier de configuration est sauvegardé
        with open(self.configFilePath, 'w') as configFile:
            config.write(configFile)

        self._parameters = config

    @property
    def password(self):
        return self._password

    @password.setter
    def password(self, value):
        keyring.set_password('DeclaTravaux', os.getlogin(), value)
        self._password = value


#!/usr/bin/env python

import sys
import locale

from PyQt5.QtWidgets import QApplication
from DeclaTravaux.main_window import MainWindow

def main():
    locale.setlocale(locale.LC_ALL, '')

    app = QApplication(sys.argv)
    mainWindow = MainWindow()
    mainWindow.show()

    rc = app.exec()
    sys.exit(rc)

main()


#!/usr/bin/env python

from PyPDF2.pdf import PdfFileReader

from pathlib import Path, PurePath
from zipfile import ZipFile, BadZipfile
from xml.etree import ElementTree

from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.base import MIMEBase
from email import encoders
from email.utils import formatdate

import re
import smtplib
import socket

from DeclaTravaux.configuration import Configuration

class TransmissionProcess():

    def __init__(self, declaration):
        self.cfg = Configuration()
        self.declaration = declaration
        self.declarationPath = Path(self.cfg['RepertoireDeclarations'], PurePath(self.declaration.fileName).stem)
        self.archiveDest = PurePath(
                            self.cfg['RepertoireDeclarations'],
                            'Archives',
                            f'{PurePath(self.declaration.fileName).stem}-d{PurePath(self.declaration.fileName).suffix}',
                            )

    def __iter__(self):

        try:
            yield 'Extraction de l’archive'
            self.extractArchive()
            
            yield 'Identification des destinataires'
            self.operators = self.getOperators()
            
            yield 'Connexion au serveur SMTP'
            self.connexion = self.getConnexion()
            
            yield 'Envoi des courriels'
            self.sentEmails = self.sendEmails()

            yield 'Envoi du courriel récapitulatif'
            self.sendRecapEmail()

            yield 'Terminé'

        except BadZipfile:
            self.undoProcess()
            yield ('ZipFileError', 'L’archive ne contient pas les données attendues ou est corrompue.')

        except socket.gaierror:
            self.undoProcess()
            yield ('ConnectionError', 'Veuillez vérifier votre connexion Internet.')

        except smtplib.SMTPAuthenticationError:
            self.undoProcess()
            yield ('AuthentificationError', 'Veuillez vérifier votre adresse électronique et votre mot de passe.')
            
    def extractArchive(self):
        """
        Extrait l'archive obtenue après l'utilisation du téléservice dans le répertoire indiqué en paramètre.
        Retourne le chemin vers le dossier où l'archive a été extraite.
        """

        # Création d'un répertoire qui contiendra le contenu extrait de l'archive ;
        # ce répertoire a pour nom le numéro de la déclaration.
        destination = PurePath(self.cfg['RepertoireDeclarations'], PurePath(self.declaration.fileName).stem)
        Path(destination).mkdir(parents=True)

        # On extrait l'ensemble du contenu de l'archive
        # dans le répertoire venant d'être créé.
        archive = ZipFile(self.declaration.filePath)
        archive.extractall(destination)
        archive.close()

        # L'archive principale contient elle-même une archive
        # On extrait donc cette sous-archive et on supprime le fichier .zip correspondant

        subArchivePath = PurePath(destination, PurePath(self.declaration.fileName).stem + '_description.zip')

        subArchive = ZipFile(subArchivePath)
        subArchive.extractall(destination)
        subArchive.close()
        Path(subArchivePath).unlink()

        # L'archive est déplacée dans le dossier « Archives » du répertoire des déclarations
        if not Path(self.cfg['RepertoireDeclarations'], 'Archives').exists():
            Path(self.cfg['RepertoireDeclarations'], 'Archives').mkdir()

        Path(self.declaration.filePath).rename(self.archiveDest)

        return True

    def getOperators(self):
        """
        Retourne la liste des destinataires définis dans le fichier ***_description.xml,
        dont le chemin est indiqué en paramètre
        """

        # On récupère le dictionnaire associant le nom de l'exploitant et son fichier PDF
        pdfList = self.associatePdf()

        # On reconstitue le chemin du fichier « *_description.xml »
        xmlFilePath = Path(self.declarationPath, PurePath(self.declaration.fileName).stem + '_description.xml')

        # On parse le fichier XML et on se place à la racine
        xmlFile = ElementTree.parse(xmlFilePath)
        root = xmlFile.getroot()

        # On indique le namespace utilisé dans le fichier XML
        ns = {'t': 'http://www.reseaux-et-canalisations.gouv.fr/schema-teleservice/2.2'}

        # On crée la liste des destinataires, qui contient l'ensemble des destinataires
        # indiqués dans le fichier XML sous la forme de dictionnaires,
        # qui contiennent un certain nombre d'informations.
        operators = list()

        # On alimente la liste des destinataires.
        for tag in root.findall('t:listeDesOuvrages/t:ouvrage', ns):

            ouvrage = tag.findtext('t:classeOuvrage', '', ns).replace('_', ' ')
            company = tag.findtext('t:contact/t:societe', '', ns)
            agency = tag.findtext('t:contact/t:agence', '', ns)
            numero = tag.findtext('t:contact/t:numero', '', ns)
            street = tag.findtext('t:contact/t:voie', '', ns)
            postcode = tag.findtext('t:contact/t:codePostal', '', ns)
            locality = tag.findtext('t:contact/t:commune', '', ns)
            countryCode = tag.findtext('t:contact/t:codePays', '', ns)
            email = tag.findtext('t:contact/t:courriel', '', ns)
            phoneNumber = tag.findtext('t:contact/t:telephone', '', ns)
            faxNumber = tag.findtext('t:contact/t:fax', '', ns)
            emergencyEmail = tag.findtext('t:contact/t:mailUrgence', '', ns)
            emergencyPhoneNumber = tag.findtext('t:contact/t:telephoneUrgence', '', ns)
            emergencyFaxNumber  = tag.findtext('t:contact/t:faxUrgence', '', ns)
            dommagePhoneNumber = tag.findtext('t:contact/t:telEndommagement', '', ns)
            dematManagement = tag.findtext('t:contact/t:gestionDesFichiersDematerialises/t:gereLesFichiersDematerialises', '', ns)
            dematFileFormat = tag.findtext('t:contact/t:gestionDesFichiersDematerialises/t:formatDesFichiersDematerialises', '', ns)

            # On associe le destinataire au fichier PDF qui lui correspond.
            if agency:
                pdfFile = [f for f, oDict in pdfList.items() if (oDict['Name'], oDict['Destinator']) == (company, agency)][0]
            else:
                pdfFile = [f for f, oDict in pdfList.items() if oDict['Name'] == company][0]
            
            # On ajoute un dictionnaire à la liste avec l'ensemble des informations récupérées.
            operators.append({'ouvrage':ouvrage, 'company':company, 'agency':agency,
                                'numero':numero, 'street':street, 'postcode':postcode,
                                'locality':locality, 'countryCode':countryCode,
                                'email':email, 'phoneNumber':phoneNumber, 'faxNumber':faxNumber,
                                'emergencyEmail':emergencyEmail,
                                'emergencyPhoneNumber':emergencyPhoneNumber,
                                'emergencyFaxNumber':emergencyFaxNumber,
                                'dommagePhoneNumber':dommagePhoneNumber,
                                'dematManagement':dematManagement,
                                'dematFileFormat':dematFileFormat,
                                'pdfFile':pdfFile
                                        })

        return operators

    def associatePdf(self):
        """
        Retourne un dictionnaire associant le nom des fichiers PDF
        au nom des exploitants concernés.

        La fonction est relativement lourde dès lors qu'elle s'appuie sur la bibliothèque PyPDF2.
        """

        pdfFileRegex = re.compile(r'[0-9]{13}[A-Z]{1}([0-9][0-9])?_(.)*_[0-9]{1,2}.pdf')
        # La liste est filtrée pour ne conserver que les formulaires PDF
        filesList = [str(f.resolve()) for f in self.declarationPath.iterdir() if pdfFileRegex.match(f.name)]
        # La liste est triée par ordre croissant
        filesList.sort()

        # Un dictionnaire est créé sous la avec la structure suivante :
        # - clé = nom du fichier PDF ;
        # - valeur = nom de l'exploitant.

        pdfDict = dict()

        for f in filesList:
            field = PdfFileReader(f).getFields()
            pdfDict[f] = dict()
            pdfDict[f]['Name'] = field['Exploitant']['/V']
            pdfDict[f]['Destinator'] = field['Destinataire']['/V']

        return pdfDict

    def getConnexion(self):
        """
        Renvoie une connexion au serveur SMTP
        """
        connexion = smtplib.SMTP_SSL(self.cfg['ServeurSMTP'], self.cfg['PortServeurSMTP'])
        connexion.login(self.cfg['AdresseElectronique'], self.cfg.password)

        return connexion

    def sendEmails(self):
        """
        Envoi par courriel des fichiers nécessaires aux différents destinataires identifiés.

        Les fichiers envoyés par courriel dépendent du niveau de dématérialisation du destinataire :
        - pas de dématérialisation : aucun courriel n'est envoyé ;
        - dématérialisation XML et PDF : envoi des fichiers « *_description.xml », « *_emprise.pdf » et « *_ZZZZ_*.pdf » ;
        - dématérialisation XML : envoi du fichier « *_description.xml ».
        """

        sentEmails = list()

        for operator in self.operators:

            # Un courriel n'est envoyé que si le destinataire gère les fichiers dématérialisés
            if operator['dematManagement']:

                # Le courriel envoyé contient un message, à la fois en version HTML et version texte, ainsi que des pièces jointes.
                #
                # Un tel courriel doit avoir la structure suivante :
                #   - Courriel (multipart/mixed)
                #       - Message (multipart/alternative)
                #           - Version texte du message (text/plain)
                #           - Version HTML du message (text/html)
                #       - Pièce jointe n° 1 (application/***)
                #       - ...
                #       - Pièce jointe n° n (application/***)


                # CRÉATION DE L'EN-TÊTE DU COURRIEL

                email = MIMEMultipart('mixed')

                email['From'] = self.cfg['AdresseElectronique']
                email['To'] = operator['email']
                email['Subject'] = 'Notification d’une déclaration de travaux'
                email['Date'] = formatdate(localtime=True)
                email['Charset'] = 'UTF-8'

                # CRÉATION DU MESSAGE (VERSION TEXTE ET VERSION HTML)

                messagePart = MIMEMultipart('alternative')


                textSubpart = """
                                Madame, Monsieur,\n
                                Veuillez trouver ci-joint les éléments
                                relatifs à une déclaration de travaux.\n
                                Meilleures salutations,\n
                                """ + self.cfg['NomExpediteur']

                htmlSubpart = """
                                <html>
                                    <head></head>
                                    <body>
                                        <p>Madame, Monsieur,</p>
                                        <p>
                                            Veuillez trouver ci-joint les éléments
                                            relatifs à une déclaration de travaux.
                                        </p>
                                        <p>Meilleures salutations,</p>
                                        <p>""" + self.cfg['NomExpediteur'] + """</p>
                                    </body>
                                </html>
                                """

                # Attribution du type MIME correspondant à chaque version
                textSubpart = MIMEText(textSubpart, 'plain')
                htmlSubpart = MIMEText(htmlSubpart, 'html')

                # Leux deux versions sont intégrées au conteneur « messagePart »
                messagePart.attach(textSubpart)
                messagePart.attach(htmlSubpart)

                # Le conteneur « messagePart » est lui-même intégré au conteneur principal « email »
                email.attach(messagePart)


                # AJOUT DES PIÈCES JOINTES

                # Les pièces jointes sont listées dans la variable « attachments »

                # Quelque soit le niveau de dématérialisation, le fichier *_description.xml est envoyé
                attachments = [self.cfg['RepertoireDeclarations'] + '/' + PurePath(self.declaration.fileName).stem + '/'
                                + PurePath(self.declaration.fileName).stem + '_description.xml',]

                # Si la dématérialisation est de type XML / PDF, il faut ajouter les fichiers *_emprise.pdf et *_ZZZZ_*.pdf
                if operator['dematFileFormat'] == 'XML_PDF':
                    # Fichier *_emprise.pdf
                    attachments.append(self.cfg['RepertoireDeclarations'] + '/' + PurePath(self.declaration.fileName).stem + '/'
                                + PurePath(self.declaration.fileName).stem + '_emprise.pdf')
                    # Fichier *_ZZZZ_*.pdf
                    attachments.append(operator['pdfFile'])

                # Chaque fichier contenu dans la variable « attachments »
                # est intégré au conteneur principal « mail » en tant que pièce jointe.
                for f in attachments:

                    attachment = open(f, 'rb')

                    attachmentPart = MIMEBase('application', 'octet-stream')
                    attachmentPart.set_payload((attachment).read())
                    encoders.encode_base64(attachmentPart)
                    attachmentPart.add_header('Content-Disposition', f'attachment; filename="{Path(f).name}"')

                    email.attach(attachmentPart)

                # Envoi du courriel
                email = email.as_string()
                self.connexion.sendmail(self.cfg['AdresseElectronique'], operator['email'], email)

                # Liste récapitulative des courriels envoyés
                sentEmails.append({'ouvrage':operator['ouvrage'],
                                'company':operator['company'],
                                'dematManagement': operator['dematManagement'],
                                'dematFileFormat':operator['dematFileFormat'],
                                'email':operator['email'],
                                'files':attachments
                                })

        return sentEmails

    def sendRecapEmail(self):
        """
        Envoie un courriel récapitulatif à l'adresse électronique de l'expéditeur.
        """

        # Le courriel envoyé contient un message, à la fois en version HTML et version texte.
        # Il n'y a pas de pièce jointe.
        #
        # Un tel courriel doit avoir la structure suivante :
        #   - Courriel (multipart/alternative)
        #       - Version texte du message (text/plain)
        #       - Version HTML du message (text/html)

        # CRÉATION DE L'EN-TÊTE DU COURRIEL

        email = MIMEMultipart('alternative')

        email['From'] = self.cfg['AdresseElectronique']
        email['To'] = self.cfg['AdresseElectronique']
        email['Subject'] = 'Récapitulatif de la transmission électronique de la déclaration de travaux'
        email['Date'] = formatdate(localtime=True)
        email['Charset'] = 'UTF-8'

        # CRÉATION DU MESSAGE (VERSION TEXTE ET VERSION HTML)

        textArray = ''
        htmlArray = ''
        htmlArray += '<table style="border-collapse: separate; border-spacing: 0px 5px; margin: auto; font-size: small;">'
        htmlArray += '<tr><th>Destinataire</th><th>Courriel</th><th>Fichiers envoyés</th></tr>'

        for entry in self.sentEmails:
            textArray += f'| {entry["company"]} | {entry["email"]} | '
            htmlArray += f'<tr><td style="border-top: 1px solid black; border-bottom: 1px solid black; padding: 4px 8px;">'
            htmlArray += f'<class style="font-weight: bold">{entry["company"]}</class><br />'
            htmlArray += f'{entry["ouvrage"]}</td>'
            htmlArray += f'<td style="border-top: 1px solid black; border-bottom: 1px solid black; padding: 4px 8px;">'
            htmlArray += f'{entry["email"]}</td>'
            htmlArray += f'<td style="border-top: 1px solid black; border-bottom: 1px solid black; padding: 4px 8px;">'

            for f in entry['files']:
                textArray += f'{Path(f).name} '
                htmlArray += f'{Path(f).name}<br />'

            textArray += ' |\n'
            htmlArray += '</td></tr>'

        htmlArray += '</table>'

        textPart = ''
        textPart += 'Voici le récapitulatif de transmission de la déclaration :\n\n'
        textPart += self.declaration.name + '\n\n'
        textPart += textArray


        htmlPart = f'''
                    <html>
                        <head></head>
                        <body>
                            <p>Voici le récapitulatif de transmission de la déclaration :</p>
                            <p style="text-align: center; font-weight: bold;">
                                {self.declaration.name}
                            </p>
                            {htmlArray}
                        </body>
                    </html>
                    '''

        # Attribution du type MIME correspondant à chaque version
        textPart = MIMEText(textPart, 'plain')
        htmlPart = MIMEText(htmlPart, 'html')

        # Leux deux versions sont intégrées au courriel
        email.attach(textPart)
        email.attach(htmlPart)

        # Envoi du courriel
        email = email.as_string()
        self.connexion.sendmail(self.cfg['AdresseElectronique'], self.cfg['AdresseElectronique'], email)

    def undoProcess(self):
        """
        Annule les déplacements de fichiers réalisés
        """

        # Le cas échéant, l'archive est rétablie dans son dossier initial
        if Path(self.archiveDest).exists():
            Path(self.archiveDest).rename(self.declaration.filePath)

        # Le cas échéant, le dossier de travail correspondant à la déclaration en cours est vidé puis supprimé
        if Path(self.declarationPath).exists():
            for f in Path(self.declarationPath).iterdir():
                Path(f).unlink()
            
            Path(self.declarationPath).rmdir()


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'DeclaTravaux/ui/main_window.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Main_Window(object):
    def setupUi(self, Main_Window):
        Main_Window.setObjectName("Main_Window")
        Main_Window.resize(600, 475)
        Main_Window.setMinimumSize(QtCore.QSize(600, 475))
        Main_Window.setMaximumSize(QtCore.QSize(600, 475))
        self.centralWidget = QtWidgets.QWidget(Main_Window)
        self.centralWidget.setObjectName("centralWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.centralWidget)
        self.verticalLayout_2.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_2.setSpacing(6)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.stackedWidget = QtWidgets.QStackedWidget(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.stackedWidget.sizePolicy().hasHeightForWidth())
        self.stackedWidget.setSizePolicy(sizePolicy)
        self.stackedWidget.setMinimumSize(QtCore.QSize(0, 400))
        self.stackedWidget.setObjectName("stackedWidget")
        self.pageStart = QtWidgets.QWidget()
        self.pageStart.setObjectName("pageStart")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.pageStart)
        self.verticalLayout.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName("verticalLayout")
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout.addItem(spacerItem)
        self.labelTitle1 = QtWidgets.QLabel(self.pageStart)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelTitle1.sizePolicy().hasHeightForWidth())
        self.labelTitle1.setSizePolicy(sizePolicy)
        self.labelTitle1.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.labelTitle1.setFont(font)
        self.labelTitle1.setAutoFillBackground(False)
        self.labelTitle1.setStyleSheet("")
        self.labelTitle1.setAlignment(QtCore.Qt.AlignCenter)
        self.labelTitle1.setIndent(0)
        self.labelTitle1.setObjectName("labelTitle1")
        self.verticalLayout.addWidget(self.labelTitle1)
        self.labelTitle2 = QtWidgets.QLabel(self.pageStart)
        self.labelTitle2.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.labelTitle2.setFont(font)
        self.labelTitle2.setStyleSheet("")
        self.labelTitle2.setAlignment(QtCore.Qt.AlignCenter)
        self.labelTitle2.setIndent(0)
        self.labelTitle2.setObjectName("labelTitle2")
        self.verticalLayout.addWidget(self.labelTitle2)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.pushButtonAbout = QtWidgets.QPushButton(self.pageStart)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonAbout.sizePolicy().hasHeightForWidth())
        self.pushButtonAbout.setSizePolicy(sizePolicy)
        self.pushButtonAbout.setStyleSheet("")
        icon = QtGui.QIcon.fromTheme("help-about")
        self.pushButtonAbout.setIcon(icon)
        self.pushButtonAbout.setCheckable(True)
        self.pushButtonAbout.setAutoDefault(True)
        self.pushButtonAbout.setObjectName("pushButtonAbout")
        self.horizontalLayout_3.addWidget(self.pushButtonAbout)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        spacerItem4 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem4)
        self.textBrowserAbout = QtWidgets.QTextBrowser(self.pageStart)
        self.textBrowserAbout.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textBrowserAbout.sizePolicy().hasHeightForWidth())
        self.textBrowserAbout.setSizePolicy(sizePolicy)
        self.textBrowserAbout.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.textBrowserAbout.setFont(font)
        self.textBrowserAbout.setStyleSheet("background-color: rgba(255, 255, 255, 0);\n"
"color: gray;")
        self.textBrowserAbout.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.textBrowserAbout.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.textBrowserAbout.setLineWidth(0)
        self.textBrowserAbout.setOpenExternalLinks(True)
        self.textBrowserAbout.setObjectName("textBrowserAbout")
        self.verticalLayout.addWidget(self.textBrowserAbout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout.addItem(spacerItem5)
        self.stackedWidget.addWidget(self.pageStart)
        self.pageParameters = QtWidgets.QWidget()
        self.pageParameters.setObjectName("pageParameters")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.pageParameters)
        self.verticalLayout_4.setContentsMargins(11, 15, 11, 15)
        self.verticalLayout_4.setSpacing(15)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.labelTitleParameters = QtWidgets.QLabel(self.pageParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelTitleParameters.sizePolicy().hasHeightForWidth())
        self.labelTitleParameters.setSizePolicy(sizePolicy)
        self.labelTitleParameters.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.labelTitleParameters.setFont(font)
        self.labelTitleParameters.setStyleSheet("")
        self.labelTitleParameters.setAlignment(QtCore.Qt.AlignCenter)
        self.labelTitleParameters.setIndent(0)
        self.labelTitleParameters.setObjectName("labelTitleParameters")
        self.verticalLayout_4.addWidget(self.labelTitleParameters)
        self.groupBox = QtWidgets.QGroupBox(self.pageParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 5px 0 5px;\n"
"}")
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setContentsMargins(11, 11, 11, 11)
        self.gridLayout.setSpacing(6)
        self.gridLayout.setObjectName("gridLayout")
        self.labelSearchDir = QtWidgets.QLabel(self.groupBox)
        self.labelSearchDir.setMinimumSize(QtCore.QSize(0, 30))
        self.labelSearchDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelSearchDir.setStyleSheet("")
        self.labelSearchDir.setObjectName("labelSearchDir")
        self.gridLayout.addWidget(self.labelSearchDir, 0, 0, 1, 1)
        self.labelWorkDir = QtWidgets.QLabel(self.groupBox)
        self.labelWorkDir.setMinimumSize(QtCore.QSize(0, 30))
        self.labelWorkDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelWorkDir.setObjectName("labelWorkDir")
        self.gridLayout.addWidget(self.labelWorkDir, 1, 0, 1, 1)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.pushButtonWorkDir = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonWorkDir.setMinimumSize(QtCore.QSize(30, 30))
        self.pushButtonWorkDir.setMaximumSize(QtCore.QSize(30, 30))
        self.pushButtonWorkDir.setAutoDefault(True)
        self.pushButtonWorkDir.setObjectName("pushButtonWorkDir")
        self.horizontalLayout_8.addWidget(self.pushButtonWorkDir)
        self.lineEditWorkDir = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditWorkDir.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditWorkDir.sizePolicy().hasHeightForWidth())
        self.lineEditWorkDir.setSizePolicy(sizePolicy)
        self.lineEditWorkDir.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditWorkDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditWorkDir.setReadOnly(True)
        self.lineEditWorkDir.setObjectName("lineEditWorkDir")
        self.horizontalLayout_8.addWidget(self.lineEditWorkDir)
        self.gridLayout.addLayout(self.horizontalLayout_8, 1, 1, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setSpacing(0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.pushButtonSearchDir = QtWidgets.QPushButton(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonSearchDir.sizePolicy().hasHeightForWidth())
        self.pushButtonSearchDir.setSizePolicy(sizePolicy)
        self.pushButtonSearchDir.setMinimumSize(QtCore.QSize(30, 30))
        self.pushButtonSearchDir.setMaximumSize(QtCore.QSize(30, 30))
        self.pushButtonSearchDir.setStyleSheet("border-width: 1px;")
        self.pushButtonSearchDir.setAutoDefault(True)
        self.pushButtonSearchDir.setObjectName("pushButtonSearchDir")
        self.horizontalLayout_7.addWidget(self.pushButtonSearchDir)
        self.lineEditSearchDir = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditSearchDir.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSearchDir.sizePolicy().hasHeightForWidth())
        self.lineEditSearchDir.setSizePolicy(sizePolicy)
        self.lineEditSearchDir.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditSearchDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditSearchDir.setStyleSheet("")
        self.lineEditSearchDir.setInputMask("")
        self.lineEditSearchDir.setReadOnly(True)
        self.lineEditSearchDir.setPlaceholderText("")
        self.lineEditSearchDir.setClearButtonEnabled(False)
        self.lineEditSearchDir.setObjectName("lineEditSearchDir")
        self.horizontalLayout_7.addWidget(self.lineEditSearchDir)
        self.gridLayout.addLayout(self.horizontalLayout_7, 0, 1, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(self.pageParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 5px 0 5px;\n"
"}")
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setContentsMargins(11, 11, 11, 11)
        self.gridLayout_2.setSpacing(6)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.horizontalWidget = QtWidgets.QWidget(self.groupBox_2)
        self.horizontalWidget.setObjectName("horizontalWidget")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.horizontalWidget)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.lineEditPassword = QtWidgets.QLineEdit(self.horizontalWidget)
        self.lineEditPassword.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditPassword.sizePolicy().hasHeightForWidth())
        self.lineEditPassword.setSizePolicy(sizePolicy)
        self.lineEditPassword.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditPassword.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditPassword.setEchoMode(QtWidgets.QLineEdit.Password)
        self.lineEditPassword.setObjectName("lineEditPassword")
        self.horizontalLayout_4.addWidget(self.lineEditPassword)
        self.gridLayout_2.addWidget(self.horizontalWidget, 1, 1, 1, 1)
        self.labelSmtpServer = QtWidgets.QLabel(self.groupBox_2)
        self.labelSmtpServer.setMinimumSize(QtCore.QSize(0, 30))
        self.labelSmtpServer.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelSmtpServer.setObjectName("labelSmtpServer")
        self.gridLayout_2.addWidget(self.labelSmtpServer, 2, 0, 1, 1)
        self.lineEditSmtpServer = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditSmtpServer.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditSmtpServer.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditSmtpServer.setInputMask("")
        self.lineEditSmtpServer.setClearButtonEnabled(True)
        self.lineEditSmtpServer.setObjectName("lineEditSmtpServer")
        self.gridLayout_2.addWidget(self.lineEditSmtpServer, 2, 1, 1, 1)
        self.lineEditSmtpPort = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditSmtpPort.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditSmtpPort.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditSmtpPort.setClearButtonEnabled(True)
        self.lineEditSmtpPort.setObjectName("lineEditSmtpPort")
        self.gridLayout_2.addWidget(self.lineEditSmtpPort, 3, 1, 1, 1)
        self.labelMail = QtWidgets.QLabel(self.groupBox_2)
        self.labelMail.setMinimumSize(QtCore.QSize(0, 30))
        self.labelMail.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelMail.setObjectName("labelMail")
        self.gridLayout_2.addWidget(self.labelMail, 0, 0, 1, 1)
        self.lineEditExpeditorName = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditExpeditorName.setMinimumSize(QtCore.QSize(0, 29))
        self.lineEditExpeditorName.setMaximumSize(QtCore.QSize(16777215, 29))
        self.lineEditExpeditorName.setClearButtonEnabled(True)
        self.lineEditExpeditorName.setObjectName("lineEditExpeditorName")
        self.gridLayout_2.addWidget(self.lineEditExpeditorName, 4, 1, 1, 1)
        self.labelSmtpPort = QtWidgets.QLabel(self.groupBox_2)
        self.labelSmtpPort.setMinimumSize(QtCore.QSize(0, 30))
        self.labelSmtpPort.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelSmtpPort.setObjectName("labelSmtpPort")
        self.gridLayout_2.addWidget(self.labelSmtpPort, 3, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_2)
        self.label.setEnabled(True)
        self.label.setMinimumSize(QtCore.QSize(0, 30))
        self.label.setMaximumSize(QtCore.QSize(16777215, 30))
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 1, 0, 1, 1)
        self.labelExpeditorName = QtWidgets.QLabel(self.groupBox_2)
        self.labelExpeditorName.setMinimumSize(QtCore.QSize(0, 30))
        self.labelExpeditorName.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelExpeditorName.setObjectName("labelExpeditorName")
        self.gridLayout_2.addWidget(self.labelExpeditorName, 4, 0, 1, 1)
        self.lineEditMail = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditMail.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditMail.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditMail.setText("")
        self.lineEditMail.setClearButtonEnabled(True)
        self.lineEditMail.setObjectName("lineEditMail")
        self.gridLayout_2.addWidget(self.lineEditMail, 0, 1, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        self.stackedWidget.addWidget(self.pageParameters)
        self.pageFileSelection = QtWidgets.QWidget()
        self.pageFileSelection.setObjectName("pageFileSelection")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.pageFileSelection)
        self.verticalLayout_10.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_10.setSpacing(6)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setContentsMargins(-1, -1, -1, 10)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        spacerItem6 = QtWidgets.QSpacerItem(561, 125, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem6)
        self.labelFileSelection = QtWidgets.QLabel(self.pageFileSelection)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelFileSelection.sizePolicy().hasHeightForWidth())
        self.labelFileSelection.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.labelFileSelection.setFont(font)
        self.labelFileSelection.setAlignment(QtCore.Qt.AlignCenter)
        self.labelFileSelection.setObjectName("labelFileSelection")
        self.verticalLayout_3.addWidget(self.labelFileSelection)
        self.verticalLayout_10.addLayout(self.verticalLayout_3)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lineEditFile = QtWidgets.QLineEdit(self.pageFileSelection)
        self.lineEditFile.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditFile.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditFile.setObjectName("lineEditFile")
        self.horizontalLayout_2.addWidget(self.lineEditFile)
        self.pushButtonBrowse = QtWidgets.QPushButton(self.pageFileSelection)
        self.pushButtonBrowse.setMinimumSize(QtCore.QSize(0, 30))
        self.pushButtonBrowse.setMaximumSize(QtCore.QSize(16777215, 30))
        self.pushButtonBrowse.setAutoDefault(True)
        self.pushButtonBrowse.setObjectName("pushButtonBrowse")
        self.horizontalLayout_2.addWidget(self.pushButtonBrowse)
        self.verticalLayout_10.addLayout(self.horizontalLayout_2)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setContentsMargins(-1, 0, -1, -1)
        self.verticalLayout_9.setSpacing(0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.labelFileError = QtWidgets.QLabel(self.pageFileSelection)
        font = QtGui.QFont()
        font.setItalic(True)
        self.labelFileError.setFont(font)
        self.labelFileError.setStyleSheet("color: rgb(226,87,76);")
        self.labelFileError.setAlignment(QtCore.Qt.AlignCenter)
        self.labelFileError.setObjectName("labelFileError")
        self.verticalLayout_9.addWidget(self.labelFileError)
        spacerItem7 = QtWidgets.QSpacerItem(561, 125, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_9.addItem(spacerItem7)
        self.verticalLayout_10.addLayout(self.verticalLayout_9)
        self.stackedWidget.addWidget(self.pageFileSelection)
        self.pageArchiveChoose = QtWidgets.QWidget()
        self.pageArchiveChoose.setObjectName("pageArchiveChoose")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.pageArchiveChoose)
        self.verticalLayout_7.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_7.setSpacing(15)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        spacerItem8 = QtWidgets.QSpacerItem(20, 32, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem8)
        self.label_2 = QtWidgets.QLabel(self.pageArchiveChoose)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.label_2.setFont(font)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_7.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.pageArchiveChoose)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.label_3.setFont(font)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_7.addWidget(self.label_3)
        spacerItem9 = QtWidgets.QSpacerItem(20, 15, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_7.addItem(spacerItem9)
        self.listWidget = QtWidgets.QListWidget(self.pageArchiveChoose)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.listWidget.setFont(font)
        self.listWidget.setViewMode(QtWidgets.QListView.ListMode)
        self.listWidget.setObjectName("listWidget")
        self.verticalLayout_7.addWidget(self.listWidget)
        spacerItem10 = QtWidgets.QSpacerItem(20, 32, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem10)
        self.stackedWidget.addWidget(self.pageArchiveChoose)
        self.pageConfirmation = QtWidgets.QWidget()
        self.pageConfirmation.setObjectName("pageConfirmation")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.pageConfirmation)
        self.verticalLayout_5.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_5.setSpacing(6)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        spacerItem11 = QtWidgets.QSpacerItem(20, 133, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem11)
        self.labelConfirmation = QtWidgets.QLabel(self.pageConfirmation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelConfirmation.sizePolicy().hasHeightForWidth())
        self.labelConfirmation.setSizePolicy(sizePolicy)
        self.labelConfirmation.setMinimumSize(QtCore.QSize(0, 0))
        self.labelConfirmation.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.labelConfirmation.setStyleSheet("")
        self.labelConfirmation.setWordWrap(True)
        self.labelConfirmation.setObjectName("labelConfirmation")
        self.verticalLayout_5.addWidget(self.labelConfirmation)
        spacerItem12 = QtWidgets.QSpacerItem(20, 133, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem12)
        self.stackedWidget.addWidget(self.pageConfirmation)
        self.pageProgress = QtWidgets.QWidget()
        self.pageProgress.setObjectName("pageProgress")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.pageProgress)
        self.verticalLayout_6.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_6.setSpacing(15)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        spacerItem13 = QtWidgets.QSpacerItem(20, 171, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem13)
        self.progressBar = QtWidgets.QProgressBar(self.pageProgress)
        self.progressBar.setMaximum(100)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setTextVisible(True)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout_6.addWidget(self.progressBar)
        self.labelStep = QtWidgets.QLabel(self.pageProgress)
        self.labelStep.setStyleSheet("font: italic;")
        self.labelStep.setAlignment(QtCore.Qt.AlignCenter)
        self.labelStep.setObjectName("labelStep")
        self.verticalLayout_6.addWidget(self.labelStep)
        spacerItem14 = QtWidgets.QSpacerItem(20, 170, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem14)
        self.stackedWidget.addWidget(self.pageProgress)
        self.pageEnd = QtWidgets.QWidget()
        self.pageEnd.setObjectName("pageEnd")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.pageEnd)
        self.verticalLayout_8.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_8.setSpacing(6)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        spacerItem15 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout_8.addItem(spacerItem15)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setSpacing(6)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem16)
        self.labelEndIcon = QtWidgets.QLabel(self.pageEnd)
        self.labelEndIcon.setMinimumSize(QtCore.QSize(100, 100))
        self.labelEndIcon.setMaximumSize(QtCore.QSize(100, 100))
        self.labelEndIcon.setText("")
        self.labelEndIcon.setScaledContents(True)
        self.labelEndIcon.setObjectName("labelEndIcon")
        self.horizontalLayout_6.addWidget(self.labelEndIcon)
        spacerItem17 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem17)
        self.verticalLayout_8.addLayout(self.horizontalLayout_6)
        spacerItem18 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout_8.addItem(spacerItem18)
        self.labelEnd1 = QtWidgets.QLabel(self.pageEnd)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.labelEnd1.setFont(font)
        self.labelEnd1.setStyleSheet("color: rgb(61, 179, 158);")
        self.labelEnd1.setAlignment(QtCore.Qt.AlignCenter)
        self.labelEnd1.setObjectName("labelEnd1")
        self.verticalLayout_8.addWidget(self.labelEnd1)
        self.labelEnd2 = QtWidgets.QLabel(self.pageEnd)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.labelEnd2.setFont(font)
        self.labelEnd2.setStyleSheet("color: rgb(61, 179, 158);")
        self.labelEnd2.setAlignment(QtCore.Qt.AlignCenter)
        self.labelEnd2.setObjectName("labelEnd2")
        self.verticalLayout_8.addWidget(self.labelEnd2)
        spacerItem19 = QtWidgets.QSpacerItem(20, 147, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem19)
        self.stackedWidget.addWidget(self.pageEnd)
        self.verticalLayout_2.addWidget(self.stackedWidget)
        self.stackedWidgetButtons = QtWidgets.QStackedWidget(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.stackedWidgetButtons.sizePolicy().hasHeightForWidth())
        self.stackedWidgetButtons.setSizePolicy(sizePolicy)
        self.stackedWidgetButtons.setObjectName("stackedWidgetButtons")
        self.stackedWidgetButtonsDefault = QtWidgets.QWidget()
        self.stackedWidgetButtonsDefault.setObjectName("stackedWidgetButtonsDefault")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.stackedWidgetButtonsDefault)
        self.horizontalLayout.setContentsMargins(10, 10, 10, 10)
        self.horizontalLayout.setSpacing(10)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButtonQuit = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonQuit.sizePolicy().hasHeightForWidth())
        self.pushButtonQuit.setSizePolicy(sizePolicy)
        self.pushButtonQuit.setMinimumSize(QtCore.QSize(120, 0))
        icon = QtGui.QIcon.fromTheme("application-exit")
        self.pushButtonQuit.setIcon(icon)
        self.pushButtonQuit.setAutoDefault(True)
        self.pushButtonQuit.setObjectName("pushButtonQuit")
        self.horizontalLayout.addWidget(self.pushButtonQuit)
        spacerItem20 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem20)
        self.pushButtonParameters = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        self.pushButtonParameters.setMinimumSize(QtCore.QSize(120, 0))
        icon = QtGui.QIcon.fromTheme("document-properties")
        self.pushButtonParameters.setIcon(icon)
        self.pushButtonParameters.setAutoDefault(True)
        self.pushButtonParameters.setObjectName("pushButtonParameters")
        self.horizontalLayout.addWidget(self.pushButtonParameters)
        spacerItem21 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem21)
        self.pushButtonPrevious = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonPrevious.sizePolicy().hasHeightForWidth())
        self.pushButtonPrevious.setSizePolicy(sizePolicy)
        self.pushButtonPrevious.setMinimumSize(QtCore.QSize(120, 0))
        icon = QtGui.QIcon.fromTheme("go-previous")
        self.pushButtonPrevious.setIcon(icon)
        self.pushButtonPrevious.setAutoDefault(True)
        self.pushButtonPrevious.setObjectName("pushButtonPrevious")
        self.horizontalLayout.addWidget(self.pushButtonPrevious)
        self.pushButtonNext = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonNext.sizePolicy().hasHeightForWidth())
        self.pushButtonNext.setSizePolicy(sizePolicy)
        self.pushButtonNext.setMinimumSize(QtCore.QSize(119, 0))
        icon = QtGui.QIcon.fromTheme("go-next")
        self.pushButtonNext.setIcon(icon)
        self.pushButtonNext.setAutoDefault(True)
        self.pushButtonNext.setDefault(True)
        self.pushButtonNext.setObjectName("pushButtonNext")
        self.horizontalLayout.addWidget(self.pushButtonNext)
        self.stackedWidgetButtons.addWidget(self.stackedWidgetButtonsDefault)
        self.stackedWidgetButtonsParameters = QtWidgets.QWidget()
        self.stackedWidgetButtonsParameters.setObjectName("stackedWidgetButtonsParameters")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.stackedWidgetButtonsParameters)
        self.horizontalLayout_5.setContentsMargins(10, 10, 10, 10)
        self.horizontalLayout_5.setSpacing(0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.pushButtonParamCancel = QtWidgets.QPushButton(self.stackedWidgetButtonsParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonParamCancel.sizePolicy().hasHeightForWidth())
        self.pushButtonParamCancel.setSizePolicy(sizePolicy)
        self.pushButtonParamCancel.setMinimumSize(QtCore.QSize(110, 0))
        icon = QtGui.QIcon.fromTheme("dialog-cancel")
        self.pushButtonParamCancel.setIcon(icon)
        self.pushButtonParamCancel.setAutoDefault(True)
        self.pushButtonParamCancel.setObjectName("pushButtonParamCancel")
        self.horizontalLayout_5.addWidget(self.pushButtonParamCancel)
        spacerItem22 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem22)
        self.pushButtonParamValidate = QtWidgets.QPushButton(self.stackedWidgetButtonsParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonParamValidate.sizePolicy().hasHeightForWidth())
        self.pushButtonParamValidate.setSizePolicy(sizePolicy)
        self.pushButtonParamValidate.setMinimumSize(QtCore.QSize(110, 0))
        icon = QtGui.QIcon.fromTheme("dialog-ok")
        self.pushButtonParamValidate.setIcon(icon)
        self.pushButtonParamValidate.setAutoDefault(True)
        self.pushButtonParamValidate.setObjectName("pushButtonParamValidate")
        self.horizontalLayout_5.addWidget(self.pushButtonParamValidate)
        self.stackedWidgetButtons.addWidget(self.stackedWidgetButtonsParameters)
        self.verticalLayout_2.addWidget(self.stackedWidgetButtons)
        Main_Window.setCentralWidget(self.centralWidget)

        self.retranslateUi(Main_Window)
        self.stackedWidget.setCurrentIndex(0)
        self.stackedWidgetButtons.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Main_Window)
        Main_Window.setTabOrder(self.pushButtonNext, self.pushButtonAbout)
        Main_Window.setTabOrder(self.pushButtonAbout, self.textBrowserAbout)
        Main_Window.setTabOrder(self.textBrowserAbout, self.lineEditFile)
        Main_Window.setTabOrder(self.lineEditFile, self.pushButtonBrowse)
        Main_Window.setTabOrder(self.pushButtonBrowse, self.listWidget)
        Main_Window.setTabOrder(self.listWidget, self.pushButtonQuit)
        Main_Window.setTabOrder(self.pushButtonQuit, self.pushButtonParameters)
        Main_Window.setTabOrder(self.pushButtonParameters, self.pushButtonPrevious)
        Main_Window.setTabOrder(self.pushButtonPrevious, self.pushButtonParamValidate)
        Main_Window.setTabOrder(self.pushButtonParamValidate, self.pushButtonSearchDir)
        Main_Window.setTabOrder(self.pushButtonSearchDir, self.lineEditSearchDir)
        Main_Window.setTabOrder(self.lineEditSearchDir, self.pushButtonWorkDir)
        Main_Window.setTabOrder(self.pushButtonWorkDir, self.lineEditWorkDir)
        Main_Window.setTabOrder(self.lineEditWorkDir, self.lineEditMail)
        Main_Window.setTabOrder(self.lineEditMail, self.lineEditPassword)
        Main_Window.setTabOrder(self.lineEditPassword, self.lineEditSmtpServer)
        Main_Window.setTabOrder(self.lineEditSmtpServer, self.lineEditSmtpPort)
        Main_Window.setTabOrder(self.lineEditSmtpPort, self.lineEditExpeditorName)
        Main_Window.setTabOrder(self.lineEditExpeditorName, self.pushButtonParamCancel)

    def retranslateUi(self, Main_Window):
        _translate = QtCore.QCoreApplication.translate
        Main_Window.setWindowTitle(_translate("Main_Window", "DéclaTravaux"))
        self.labelTitle1.setText(_translate("Main_Window", "DéclaTravaux"))
        self.labelTitle2.setText(_translate("Main_Window", "Utilitaire de déclarations de travaux"))
        self.pushButtonAbout.setText(_translate("Main_Window", "À propos"))
        self.textBrowserAbout.setHtml(_translate("Main_Window", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Utilitaire de télétransmission des DT, DICT et ATU.</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Logiciel développé en Python par Pierre Gobin.</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Disponible sous la licence libre CeCILL (</span><a href=\"http://www.cecill.info/\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">http://www.cecill.info/</span></a><span style=\" font-size:11pt;\">).</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Images réalisées par </span><a href=\"https://www.flaticon.com/authors/pixel-buddha\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">Pixel Buddha</span></a><span style=\" font-size:11pt;\"> sur </span><a href=\"https://www.flaticon.com\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">www.flaticon.com</span></a><span style=\" font-size:11pt;\">.</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Plus d\'informations sur </span><a href=\"https://framagit.org/Pierre86/DeclaTravaux\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">Framagit</span></a><span style=\" font-size:11pt;\">.</span></p></body></html>"))
        self.labelTitleParameters.setText(_translate("Main_Window", "Paramètres"))
        self.groupBox.setTitle(_translate("Main_Window", "Configuration"))
        self.labelSearchDir.setText(_translate("Main_Window", "Répertoire de recherche :"))
        self.labelWorkDir.setText(_translate("Main_Window", "Répertoire de traitement :"))
        self.pushButtonWorkDir.setText(_translate("Main_Window", "..."))
        self.pushButtonSearchDir.setText(_translate("Main_Window", "..."))
        self.groupBox_2.setTitle(_translate("Main_Window", "Courriels"))
        self.lineEditPassword.setPlaceholderText(_translate("Main_Window", "Mot de passe"))
        self.labelSmtpServer.setText(_translate("Main_Window", "Adresse du serveur SMTP :"))
        self.lineEditSmtpServer.setPlaceholderText(_translate("Main_Window", "smtp.domaine.com"))
        self.lineEditSmtpPort.setPlaceholderText(_translate("Main_Window", "Ex. : 465"))
        self.labelMail.setText(_translate("Main_Window", "Adresse électronique :"))
        self.lineEditExpeditorName.setPlaceholderText(_translate("Main_Window", "Prénom NOM"))
        self.labelSmtpPort.setText(_translate("Main_Window", "Port du serveur SMTP :"))
        self.label.setText(_translate("Main_Window", "Mot de passe :"))
        self.labelExpeditorName.setText(_translate("Main_Window", "Nom de l\'expéditeur :"))
        self.lineEditMail.setPlaceholderText(_translate("Main_Window", "exemple@domaine.com"))
        self.labelFileSelection.setText(_translate("Main_Window", "Sélectionner une archive :"))
        self.pushButtonBrowse.setText(_translate("Main_Window", "Parcourir..."))
        self.labelFileError.setText(_translate("Main_Window", "Le format de l\'archive sélectionnée est incorrect."))
        self.label_2.setText(_translate("Main_Window", "Plusieurs archives ont été trouvées."))
        self.label_3.setText(_translate("Main_Window", "Veuillez choisir la déclaration que vous souhaitez télétransmettre :"))
        self.labelConfirmation.setText(_translate("Main_Window", "<html><head/>\n"
"<style type=\"text/css\">\n"
"p {margin: 15px; line-height: 125; font-size: 14pt; text-align: center;}\n"
"#numero, #date {font-weight: bold;}\n"
"</style>\n"
"<body>\n"
"<p>\n"
"La déclaration n<span style=\"vertical-align: super;\">o</span> <span id=\"numero\">XXX</span> du <span id=\"date\">JJ MMMM AAAA</span>\n"
"<br />\n"
"a été sélectionnée.</p>\n"
"<p>Souhaitez-vous procéder à sa télétransmission ?</p>\n"
"</body>\n"
"</html>"))
        self.progressBar.setFormat(_translate("Main_Window", "%p %"))
        self.labelStep.setText(_translate("Main_Window", "Extraction de l\'archive..."))
        self.labelEnd1.setText(_translate("Main_Window", "La déclaration a été télétransmise."))
        self.labelEnd2.setText(_translate("Main_Window", "Un courriel récapitulatif a été envoyé à xxx@domaine.tld"))
        self.pushButtonQuit.setText(_translate("Main_Window", "Quitter"))
        self.pushButtonParameters.setText(_translate("Main_Window", "Paramètres"))
        self.pushButtonPrevious.setText(_translate("Main_Window", "Précédent"))
        self.pushButtonNext.setText(_translate("Main_Window", "Démarrer"))
        self.pushButtonParamCancel.setText(_translate("Main_Window", "Annuler"))
        self.pushButtonParamValidate.setText(_translate("Main_Window", "Valider"))




#!/usr/bin/env python

import os
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(name='DeclaTravaux',
    version='0.1',
    description='Utilitaire de transmission de déclarations issues de la plateforme http://www.reseaux-et-canalisations.ineris.fr/',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    author='Pierre Gobin',
    author_email='contact@pierregobin.fr',
    url='https://framagit.org/Pierre86/DeclaTravaux',
    license='CeCILL',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Office/Business',
        'License :: OSI Approved :: CEA CNRS Inria Logiciel Libre License, version 2.1 (CeCILL-2.1)',
        'Programming Language :: Python :: 3',
    ],
    packages=find_packages(),
    install_requires=[
        'keyring>=10.4.0',
        'PyPDF2>=1.26.0',
        'PyQt5>=5.10',
    ],
    python_requires='>=3',
    entry_points={
        'gui_scripts': [
            'DeclaTravaux = DeclaTravaux.__main__:main',
        ],
    },
)
